import setuptools

with open("README.md", "r") as fh:
  long_description = fh.read()

with open('requirements.txt') as f:
  requirements = f.read().splitlines()

with open('requirements-install.txt') as f:
  for req in f.read().splitlines():
    requirements.append(req)

setuptools.setup(
  name="eipiphany-time",
  version="0.1.0.dev20230202193914",
  description="Simple Multiprocessing EIP Framework For Python: Time Components",
  long_description=long_description,
  long_description_content_type="text/markdown",
  url="https://github.com/ci-cmg/eipiphany",
  package_dir={'': 'src'},
  packages=setuptools.find_packages('src'),
  classifiers=[
    "Programming Language :: Python :: 3",
    "License :: OSI Approved :: MIT License",
    "Operating System :: OS Independent",
  ],
  python_requires='>=3.9',
  install_requires=[req for req in requirements if req[:2] != "# "]
)


from eipiphany_core.framework.base.endpoint import Endpoint

from .time_interval_configuration import TimeIntervalConfiguration
from .time_interval_source import TimeIntervalSource


class TimeIntervalEndpoint(Endpoint):

  def __init__(self, primary_id, source_configuration = None):
    super().__init__(primary_id)
    self.__default_config = TimeIntervalConfiguration()
    self.__source_configuration = source_configuration
    if not self.__source_configuration:
      self.__source_configuration = self.__default_config
    self.__source = TimeIntervalSource(self.__source_configuration)

  def get_prefix(self):
    return 'time-interval'

  def process(self, exchange, configuration):
    raise Exception("time-interval endpoint only supports producer endpoints")

  def get_source(self):
    return self.__source